==> haskell-th-desugar-1.8-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-desugar
version: 1.8
id: th-desugar-1.8-ABPsKnfQjrNBoG1ReYFbr0
key: th-desugar-1.8-ABPsKnfQjrNBoG1ReYFbr0
license: BSD-3-Clause
maintainer: Richard Eisenberg <rae@cs.brynmawr.edu>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Richard Eisenberg <rae@cs.brynmawr.edu>
stability: experimental
homepage: https://github.com/goldfirere/th-desugar
synopsis: Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.
category: Template Haskell
abi: 25d356184317d77a233a2e6e49e536a1
exposed: True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten
hidden-modules: Language.Haskell.TH.Desugar.Core
                Language.Haskell.TH.Desugar.Match Language.Haskell.TH.Desugar.Util
                Language.Haskell.TH.Desugar.Reify
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-desugar-1.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-desugar-1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-desugar-1.8
hs-libraries: HSth-desugar-1.8-ABPsKnfQjrNBoG1ReYFbr0
depends:
    base-4.11.1.0 template-haskell-2.13.0.0 containers-0.5.11.0
    mtl-2.2.2 syb-0.7-2jW43lwzJV5e7EQvU8PxV
    th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr
    th-orphans-0.13.6-2ZWsbOUc8WC8u7Ssjb29JP
    th-expand-syns-0.4.4.0-47lN8Q4mjVf9oH66olShaZ
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr=3abe31b2134622b7b297c47726ab60c8
             th-orphans-0.13.6-2ZWsbOUc8WC8u7Ssjb29JP=62fdd7dbe5997dd3b25279338b8935f6
             th-expand-syns-0.4.4.0-47lN8Q4mjVf9oH66olShaZ=57b52efb7f11d7306705f04857c849df
haddock-interfaces: /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html: /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-desugar-1.8-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-desugar
version: 1.8
id: th-desugar-1.8-HG6Toknccvx84RJuwKG8YF
key: th-desugar-1.8-HG6Toknccvx84RJuwKG8YF
license: BSD-3-Clause
maintainer: Richard Eisenberg <rae@cs.brynmawr.edu>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Richard Eisenberg <rae@cs.brynmawr.edu>
stability: experimental
homepage: https://github.com/goldfirere/th-desugar
synopsis: Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.
category: Template Haskell
abi: 9210909c5ea10c3b87cafbcc3cb953de
exposed: True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten
hidden-modules: Language.Haskell.TH.Desugar.Core
                Language.Haskell.TH.Desugar.Match Language.Haskell.TH.Desugar.Util
                Language.Haskell.TH.Desugar.Reify
import-dirs: /usr/lib/ghc-8.4.3/site-local/th-desugar-1.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/th-desugar-1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/th-desugar-1.8
hs-libraries: HSth-desugar-1.8-HG6Toknccvx84RJuwKG8YF
depends:
    base-4.11.1.0 template-haskell-2.13.0.0 containers-0.5.11.0
    mtl-2.2.2 syb-0.7-2jW43lwzJV5e7EQvU8PxV
    th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr
    th-orphans-0.13.6-B7DioG8r06lEZINhBF3aT7
    th-expand-syns-0.4.4.0-47lN8Q4mjVf9oH66olShaZ
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             th-lift-0.7.11-EZ6htAQX8IAAgCBukhymGr=3abe31b2134622b7b297c47726ab60c8
             th-orphans-0.13.6-B7DioG8r06lEZINhBF3aT7=847c37d7a458a8d6dd82ba377e002ba0
             th-expand-syns-0.4.4.0-47lN8Q4mjVf9oH66olShaZ=57b52efb7f11d7306705f04857c849df
haddock-interfaces: /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html: /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
